searchData={"items":[{"type":"module","title":"ExlasticSearch","doc":"A collection of Elasticsearch DSL's to make development simple.\n\nThe usage is meant to pair with existing ecto schema, like so:\n\n    defmodule MySchema do\n      ...\n      use ExlasticSearch.Model\n\n      indexes :my_index do\n        settings Application.get_env(:some, :settings)\n\n        mapping :field\n        mapping :other_field, type: :keyword # ecto derived defaults can be overridden\n      end\n    end\n\nYou can then construct queries like so:\n\n    MySchema.search_query()\n    |> must(match(field, value))\n    |> should(match_phrase(field, value, opts))\n    |> filter(term(filter_field, value))\n\nA Repo model like Ecto is provided, so a with ability to do most restful operations on records, in\naddition to calling search apis with the query structs above.\n\nIf additional data needs to be fetched or formatted prior to insertion into elastic, the `ExlasticSearch.Indexable`\nprotocol can be implemented to do that for you. A default implementation can also be generated as part of using\nthe `ExlasticSearch.Model` macro.","ref":"ExlasticSearch.html"},{"type":"module","title":"ExlasticSearch.Aggregation","doc":"Elasticsearch aggregation building functions.","ref":"ExlasticSearch.Aggregation.html"},{"type":"function","title":"ExlasticSearch.Aggregation.composite/4","doc":"A composite aggregation.","ref":"ExlasticSearch.Aggregation.html#composite/4"},{"type":"function","title":"ExlasticSearch.Aggregation.composite_source/3","doc":"The source for a composite aggregation, eg `composite_source(:age, :terms, field: :age)`.","ref":"ExlasticSearch.Aggregation.html#composite_source/3"},{"type":"function","title":"ExlasticSearch.Aggregation.nest/3","doc":"Includes a given aggregation within the aggregation with name `name`.","ref":"ExlasticSearch.Aggregation.html#nest/3"},{"type":"function","title":"ExlasticSearch.Aggregation.new/0","doc":"Create a new aggregation specification.","ref":"ExlasticSearch.Aggregation.html#new/0"},{"type":"function","title":"ExlasticSearch.Aggregation.realize/1","doc":"Convert to the es representation of the aggregation.","ref":"ExlasticSearch.Aggregation.html#realize/1"},{"type":"type","title":"ExlasticSearch.Aggregation.t/0","doc":"","ref":"ExlasticSearch.Aggregation.html#t:t/0"},{"type":"function","title":"ExlasticSearch.Aggregation.terms/3","doc":"Bucket a query by a given term","ref":"ExlasticSearch.Aggregation.html#terms/3"},{"type":"function","title":"ExlasticSearch.Aggregation.top_hits/3","doc":"Return the top results for a query or aggregation scope.","ref":"ExlasticSearch.Aggregation.html#top_hits/3"},{"type":"function","title":"ExlasticSearch.Aggregation.with_nested/3","doc":"","ref":"ExlasticSearch.Aggregation.html#with_nested/3"},{"type":"module","title":"ExlasticSearch.BulkOperation","doc":"Handles bulk request generation.","ref":"ExlasticSearch.BulkOperation.html"},{"type":"function","title":"ExlasticSearch.BulkOperation.bulk_operation/1","doc":"Generates a request for inserts, updates and deletes\nthat can be sent as a bulk request using Elastix.","ref":"ExlasticSearch.BulkOperation.html#bulk_operation/1"},{"type":"protocol","title":"ExlasticSearch.Indexable","doc":"Protocol for converting Ecto structs to ES-compatible maps.\n\n`ExlasticSearch.Repo` uses this internally to effect any conversion prior to communicating with Elasticsearch itself.","ref":"ExlasticSearch.Indexable.html"},{"type":"function","title":"ExlasticSearch.Indexable.document/1","doc":"Properties map to be inserted into ES.","ref":"ExlasticSearch.Indexable.html#document/1"},{"type":"function","title":"ExlasticSearch.Indexable.document/2","doc":"Properties map to be inserted into ES.","ref":"ExlasticSearch.Indexable.html#document/2"},{"type":"function","title":"ExlasticSearch.Indexable.id/1","doc":"ES record id.","ref":"ExlasticSearch.Indexable.html#id/1"},{"type":"function","title":"ExlasticSearch.Indexable.preload/1","doc":"Any preloads needed to call `document/2`.","ref":"ExlasticSearch.Indexable.html#preload/1"},{"type":"function","title":"ExlasticSearch.Indexable.preload/2","doc":"Any preloads needed to call `document/2`.","ref":"ExlasticSearch.Indexable.html#preload/2"},{"type":"type","title":"ExlasticSearch.Indexable.t/0","doc":"All the types that implement this protocol.","ref":"ExlasticSearch.Indexable.html#t:t/0"},{"type":"module","title":"ExlasticSearch.Model","doc":"Base macro for generating elasticsearch modules.\n\nIs intended to be used in conjunction with a Ecto model (although that is not strictly necessary).\n\nIt includes three primary macros:\n\n* `indexes/2`\n* `settings/1`\n* `mapping/2`\n\nThe usage is something like this\n\n    indexes :my_type do\n      settings Application.get_env(:some, :settings)\n\n      mapping :column\n      mapping :other_column, type: :keyword\n    end\n\nThis will set up settings and mappings for index my_types with type my_type (specify the singularized\ntype in the macro, so pluralization works naturally).\n\nThe following functions will also be created:\n\n* `__es_mappings__/0` - map of all fully specified mappings for the given type\n* `__mappings__/0` - columns with mappings for the given type\n* `__es_index__/0` - the elasticsearch index for this model\n* `__es_index__/1` - the elasticsearch index for reads/writes when performing zero-downtime updates\n(pass either `:read` or `:index` respectively)\n* `__doc_type__/0` - the default document type for searches in __es_index__()\n* `__es_settings__/0` - the settings for the index of this model","ref":"ExlasticSearch.Model.html"},{"type":"function","title":"ExlasticSearch.Model.ecto_to_es/1","doc":"","ref":"ExlasticSearch.Model.html#ecto_to_es/1"},{"type":"function","title":"ExlasticSearch.Model.es_decode/2","doc":"Converts a search result to `model`'s search result type.","ref":"ExlasticSearch.Model.html#es_decode/2"},{"type":"function","title":"ExlasticSearch.Model.index_version/1","doc":"","ref":"ExlasticSearch.Model.html#index_version/1"},{"type":"function","title":"ExlasticSearch.Model.index_version/2","doc":"","ref":"ExlasticSearch.Model.html#index_version/2"},{"type":"macro","title":"ExlasticSearch.Model.indexes/3","doc":"Opens up index definition for the current model.\n\nWill name the index and generate metadata attributes for the index based on subsequent calls to `settings/1` and `mappings/2`.\n\nAccepts:\n\n  * `type` - the indexes type (and index name will be `type <> \"s\"`)\n  * `block` - the definition of the index","ref":"ExlasticSearch.Model.html#indexes/3"},{"type":"macro","title":"ExlasticSearch.Model.mapping/2","doc":"Adds a new mapping to the ES schema.\n\nThe type of the mapping will be inferred automatically, unless explicitly set in props.\n\nAccepts:\n\n  * `name` - the name of the mapping\n  * `props` - is a map/kw list of ES mapping configuration (e.g. `search_analyzer: \"my_search_analyzer\", type: \"text\"`)","ref":"ExlasticSearch.Model.html#mapping/2"},{"type":"function","title":"ExlasticSearch.Model.mapping_template/1","doc":"","ref":"ExlasticSearch.Model.html#mapping_template/1"},{"type":"macro","title":"ExlasticSearch.Model.options/1","doc":"","ref":"ExlasticSearch.Model.html#options/1"},{"type":"macro","title":"ExlasticSearch.Model.settings/1","doc":"A map of index settings. Structure is the same as specified by ES.","ref":"ExlasticSearch.Model.html#settings/1"},{"type":"macro","title":"ExlasticSearch.Model.versions/1","doc":"","ref":"ExlasticSearch.Model.html#versions/1"},{"type":"module","title":"ExlasticSearch.Model.SearchResult","doc":"Wrapper for a models search result. Used for response parsing.","ref":"ExlasticSearch.Model.SearchResult.html"},{"type":"module","title":"ExlasticSearch.Query","doc":"Elasticsearch query building functions.\n\nBasic usage for queryable Queryable is something like:\n\n    Queryable.search_query()\n    |> must(match(field, value))\n    |> should(match_phrase(field, value, opts))\n    |> filter(term(filter_field, value))\n    |> realize()\n\nAn ES query has 3 main clauses, must, should and filter. Must and should are near equivalents\nexcept that must clauses will reject records that fail to match.\n\nFilters require matches but do not contribute to scoring, while must/should both do.\nNesting queries within queries is also supported\n\nCurrently the module only supports the boolean style of compound query, but we could add support\nfor the others as need be.\n\nSee https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl.html for documentation\non specific query types.","ref":"ExlasticSearch.Query.html"},{"type":"type","title":"ExlasticSearch.Query.field/0","doc":"","ref":"ExlasticSearch.Query.html#t:field/0"},{"type":"function","title":"ExlasticSearch.Query.field_value_factor/3","doc":"","ref":"ExlasticSearch.Query.html#field_value_factor/3"},{"type":"function","title":"ExlasticSearch.Query.filter/2","doc":"Appends a new filter scope to the running query.","ref":"ExlasticSearch.Query.html#filter/2"},{"type":"function","title":"ExlasticSearch.Query.function_score/3","doc":"","ref":"ExlasticSearch.Query.html#function_score/3"},{"type":"function","title":"ExlasticSearch.Query.ids/1","doc":"ids query clause.","ref":"ExlasticSearch.Query.html#ids/1"},{"type":"function","title":"ExlasticSearch.Query.match/2","doc":"Builds a match query clause.","ref":"ExlasticSearch.Query.html#match/2"},{"type":"function","title":"ExlasticSearch.Query.match/3","doc":"","ref":"ExlasticSearch.Query.html#match/3"},{"type":"function","title":"ExlasticSearch.Query.match_phrase/3","doc":"Builds a match phrase query clause.","ref":"ExlasticSearch.Query.html#match_phrase/3"},{"type":"function","title":"ExlasticSearch.Query.multi_match/3","doc":"Multimatch query clause.","ref":"ExlasticSearch.Query.html#multi_match/3"},{"type":"function","title":"ExlasticSearch.Query.must/2","doc":"Appends a new must scope to the running query.","ref":"ExlasticSearch.Query.html#must/2"},{"type":"function","title":"ExlasticSearch.Query.must_not/2","doc":"Appends a new must_not scope to the running query.","ref":"ExlasticSearch.Query.html#must_not/2"},{"type":"function","title":"ExlasticSearch.Query.nested/2","doc":"","ref":"ExlasticSearch.Query.html#nested/2"},{"type":"function","title":"ExlasticSearch.Query.options/2","doc":"Add options to the current bool compound query (for instance the minimum number of accepted matches).","ref":"ExlasticSearch.Query.html#options/2"},{"type":"function","title":"ExlasticSearch.Query.query_string/2","doc":"Query string query type, that applies ES standard query rewriting.","ref":"ExlasticSearch.Query.html#query_string/2"},{"type":"function","title":"ExlasticSearch.Query.range/2","doc":"Range query clause.","ref":"ExlasticSearch.Query.html#range/2"},{"type":"function","title":"ExlasticSearch.Query.realize/1","doc":"Converts a `Query` struct into an ES compliant bool or function score compound query.","ref":"ExlasticSearch.Query.html#realize/1"},{"type":"function","title":"ExlasticSearch.Query.script_score/3","doc":"Converts a query to a function score query and adds the given `script` for scoring.","ref":"ExlasticSearch.Query.html#script_score/3"},{"type":"function","title":"ExlasticSearch.Query.should/2","doc":"Appends a new should scope to the running query.","ref":"ExlasticSearch.Query.html#should/2"},{"type":"function","title":"ExlasticSearch.Query.sort/3","doc":"Adds a sort clause to the ES query.","ref":"ExlasticSearch.Query.html#sort/3"},{"type":"type","title":"ExlasticSearch.Query.t/0","doc":"","ref":"ExlasticSearch.Query.html#t:t/0"},{"type":"function","title":"ExlasticSearch.Query.term/2","doc":"Term query clause.","ref":"ExlasticSearch.Query.html#term/2"},{"type":"function","title":"ExlasticSearch.Query.terms/2","doc":"Terms query clause.","ref":"ExlasticSearch.Query.html#terms/2"},{"type":"module","title":"ExlasticSearch.Repo","doc":"API executor for elasticsearch.\n\nThe generate pattern is to define a `ExlasticSearch.Model` on an Ecto model, then call any of these functions to manage the model.\n\nTo configure the URL the repo points to, do:\n\n    config :exlasticsearch, ExlasticSearch.Repo,\n      url: \"https://elasticsearch.url.io:9200\"","ref":"ExlasticSearch.Repo.html"},{"type":"function","title":"ExlasticSearch.Repo.aggregate/2","doc":"Performs an aggregation against a query, and returns only the aggregation results.","ref":"ExlasticSearch.Repo.html#aggregate/2"},{"type":"function","title":"ExlasticSearch.Repo.bulk/4","doc":"Generates an Elasticsearch bulk request. `operations` should be of the form:\n\n    [\n      {:index, struct, index},\n      {:delete, other_struct, index},\n      {:update, third_struct, id, map, index}\n    ]\n\nNote: the last element in each Tuple is optional and will default to `:index`.\n\nThe function will handle formatting the bulk request properly and passing each\nstruct to the `ExlasticSearch.Indexable` protocol.","ref":"ExlasticSearch.Repo.html#bulk/4"},{"type":"function","title":"ExlasticSearch.Repo.close_index/2","doc":"Close an index for `model`.","ref":"ExlasticSearch.Repo.html#close_index/2"},{"type":"function","title":"ExlasticSearch.Repo.create_alias/3","doc":"Aliases one index version to another, for instance:\n\n    alias(MyModel, read: :index)\n\nWill create an alias of the read version of the model's index\nagainst it's indexing version.","ref":"ExlasticSearch.Repo.html#create_alias/3"},{"type":"function","title":"ExlasticSearch.Repo.create_index/2","doc":"Creates an index as defined in `model`.","ref":"ExlasticSearch.Repo.html#create_index/2"},{"type":"function","title":"ExlasticSearch.Repo.create_mapping/3","doc":"Updates an index's mappings to the current definition in `model`.","ref":"ExlasticSearch.Repo.html#create_mapping/3"},{"type":"function","title":"ExlasticSearch.Repo.delete/2","doc":"Removes `struct` from the index of its model.","ref":"ExlasticSearch.Repo.html#delete/2"},{"type":"function","title":"ExlasticSearch.Repo.delete_index/2","doc":"Removes the index defined in `model`.","ref":"ExlasticSearch.Repo.html#delete_index/2"},{"type":"function","title":"ExlasticSearch.Repo.exists?/2","doc":"Checks if the index for `model` exists.","ref":"ExlasticSearch.Repo.html#exists?/2"},{"type":"function","title":"ExlasticSearch.Repo.get/2","doc":"Gets an ES document by `_id`.","ref":"ExlasticSearch.Repo.html#get/2"},{"type":"function","title":"ExlasticSearch.Repo.get_alias/2","doc":"Retries the aliases for a given index.","ref":"ExlasticSearch.Repo.html#get_alias/2"},{"type":"function","title":"ExlasticSearch.Repo.index/2","doc":"Adds a struct into it's associated index.\n\nThe struct will be passed through the `ExlasticSearch.Indexable`\nprotocol prior to insertion.","ref":"ExlasticSearch.Repo.html#index/2"},{"type":"function","title":"ExlasticSearch.Repo.index_stream/4","doc":"","ref":"ExlasticSearch.Repo.html#index_stream/4"},{"type":"function","title":"ExlasticSearch.Repo.json_library/0","doc":"","ref":"ExlasticSearch.Repo.html#json_library/0"},{"type":"function","title":"ExlasticSearch.Repo.open_index/2","doc":"Open an index for `model`.","ref":"ExlasticSearch.Repo.html#open_index/2"},{"type":"function","title":"ExlasticSearch.Repo.paginate/2","doc":"","ref":"ExlasticSearch.Repo.html#paginate/2"},{"type":"function","title":"ExlasticSearch.Repo.refresh/2","doc":"Refreshes `model`'s index.","ref":"ExlasticSearch.Repo.html#refresh/2"},{"type":"type","title":"ExlasticSearch.Repo.response/0","doc":"","ref":"ExlasticSearch.Repo.html#t:response/0"},{"type":"function","title":"ExlasticSearch.Repo.rotate/3","doc":"Deletes the read index and aliases the write index to it.","ref":"ExlasticSearch.Repo.html#rotate/3"},{"type":"function","title":"ExlasticSearch.Repo.scrivener_defaults/0","doc":"","ref":"ExlasticSearch.Repo.html#scrivener_defaults/0"},{"type":"function","title":"ExlasticSearch.Repo.search/2","doc":"Creates a call to `search/3` by realizing `query` (using `Exlasticsearch.Query.realize/1`) and any provided search opts.","ref":"ExlasticSearch.Repo.html#search/2"},{"type":"function","title":"ExlasticSearch.Repo.search/4","doc":"Searches the index and type associated with `model` according to query `search`.","ref":"ExlasticSearch.Repo.html#search/4"},{"type":"function","title":"ExlasticSearch.Repo.update/4","doc":"Updates the document of the passed in id for the index associated to the model.","ref":"ExlasticSearch.Repo.html#update/4"},{"type":"function","title":"ExlasticSearch.Repo.update_by_query/4","doc":"Updates all document based on the query using the provided script.","ref":"ExlasticSearch.Repo.html#update_by_query/4"},{"type":"function","title":"ExlasticSearch.Repo.update_index/2","doc":"Updates the index for `model`.","ref":"ExlasticSearch.Repo.html#update_index/2"},{"type":"module","title":"ExlasticSearch.Response","doc":"Base module for ES response parsing.\n\nWorks off a few macros, `schema/1`, `field/1`, `has_many/2`, `has_one/2`.\n\nThe usage is more or less:\n\n    use ExlasticSearch.Response\n\n    schema do\n      field :total\n\n      has_many :hits, HitsModule\n    end\n\nThis will define:\n\n  * a struct for carrying the response\n  * `parse/2` - converts a json decoded map from ES to the given response struct, and converting any models appropriately\n  * `to_model/2` - performs model conversion if possible (defaults to no-op)","ref":"ExlasticSearch.Response.html"},{"type":"function","title":"ExlasticSearch.Response.convert_keys/2","doc":"Safe conversion of string keyed ES response maps to structifiable atom keyed maps.","ref":"ExlasticSearch.Response.html#convert_keys/2"},{"type":"macro","title":"ExlasticSearch.Response.field/1","doc":"Adds a simple field attribute.","ref":"ExlasticSearch.Response.html#field/1"},{"type":"macro","title":"ExlasticSearch.Response.has_many/2","doc":"Adds a has_many relation or the parser, which assumes a list value.\n\nAccepts:\n\n  * field - the name of the relation\n  * parser - module of the responsible parser for parsing it","ref":"ExlasticSearch.Response.html#has_many/2"},{"type":"macro","title":"ExlasticSearch.Response.has_one/2","doc":"Adds a has_one relation or the parser.\n\nAccepts:\n\n  * field - the name of the relation\n  * parser - module of the responsible parser for parsing it","ref":"ExlasticSearch.Response.html#has_one/2"},{"type":"function","title":"ExlasticSearch.Response.parse_associations/4","doc":"Utility for recursively parsing response associations.","ref":"ExlasticSearch.Response.html#parse_associations/4"},{"type":"macro","title":"ExlasticSearch.Response.schema/1","doc":"Opens up the schema definition macro.  Once closed, the following will be defined:\n\n  * `__schema__(:parse_spec)` - A table for converting string keyed maps to atom keyed\n  * `__schema__(:attributes)` - basic field attributes\n  * `__schema__(:associations)` - a table of associations for the response, along with the responsible parser","ref":"ExlasticSearch.Response.html#schema/1"},{"type":"module","title":"ExlasticSearch.Response.Hits","doc":"Elasticsearch hits response structure.","ref":"ExlasticSearch.Response.Hits.html"},{"type":"function","title":"ExlasticSearch.Response.Hits.new/1","doc":"","ref":"ExlasticSearch.Response.Hits.html#new/1"},{"type":"function","title":"ExlasticSearch.Response.Hits.parse/3","doc":"","ref":"ExlasticSearch.Response.Hits.html#parse/3"},{"type":"function","title":"ExlasticSearch.Response.Hits.to_model/3","doc":"","ref":"ExlasticSearch.Response.Hits.html#to_model/3"},{"type":"module","title":"ExlasticSearch.Response.Record","doc":"Elasticsearch record response structure.\n\n`:_source` can contain a parsed model result if properly specified.","ref":"ExlasticSearch.Response.Record.html"},{"type":"function","title":"ExlasticSearch.Response.Record.new/1","doc":"","ref":"ExlasticSearch.Response.Record.html#new/1"},{"type":"function","title":"ExlasticSearch.Response.Record.parse/3","doc":"","ref":"ExlasticSearch.Response.Record.html#parse/3"},{"type":"function","title":"ExlasticSearch.Response.Record.to_model/3","doc":"","ref":"ExlasticSearch.Response.Record.html#to_model/3"},{"type":"module","title":"ExlasticSearch.Response.Search","doc":"Elasticsearch Search response structure.","ref":"ExlasticSearch.Response.Search.html"},{"type":"function","title":"ExlasticSearch.Response.Search.new/1","doc":"","ref":"ExlasticSearch.Response.Search.html#new/1"},{"type":"function","title":"ExlasticSearch.Response.Search.parse/3","doc":"","ref":"ExlasticSearch.Response.Search.html#parse/3"},{"type":"function","title":"ExlasticSearch.Response.Search.to_model/3","doc":"","ref":"ExlasticSearch.Response.Search.html#to_model/3"},{"type":"module","title":"ExlasticSearch.Retry.Decorator","doc":"Decorator for applying retry strategies to a function.\n\nConfigure with:\n\n    config :exlasticsearch, :retry, strategy: MyStrategy, additional_opts","ref":"ExlasticSearch.Retry.Decorator.html"},{"type":"macro","title":"ExlasticSearch.Retry.Decorator.retry/0","doc":"","ref":"ExlasticSearch.Retry.Decorator.html#retry/0"},{"type":"function","title":"ExlasticSearch.Retry.Decorator.retry/2","doc":"","ref":"ExlasticSearch.Retry.Decorator.html#retry/2"},{"type":"module","title":"ExlasticSearch.Retry.ExponentialBackoff","doc":"Retry Strategy implementation utilizing exponential backoffs.","ref":"ExlasticSearch.Retry.ExponentialBackoff.html"},{"type":"function","title":"ExlasticSearch.Retry.ExponentialBackoff.retry/2","doc":"","ref":"ExlasticSearch.Retry.ExponentialBackoff.html#retry/2"},{"type":"behaviour","title":"ExlasticSearch.RetryStrategy","doc":"Behavior for retrying a 0-arity function according to some strategy.","ref":"ExlasticSearch.RetryStrategy.html"},{"type":"type","title":"ExlasticSearch.RetryStrategy.callable/0","doc":"","ref":"ExlasticSearch.RetryStrategy.html#t:callable/0"},{"type":"type","title":"ExlasticSearch.RetryStrategy.response/0","doc":"","ref":"ExlasticSearch.RetryStrategy.html#t:response/0"},{"type":"callback","title":"ExlasticSearch.RetryStrategy.retry/2","doc":"","ref":"ExlasticSearch.RetryStrategy.html#c:retry/2"},{"type":"module","title":"ExlasticSearch.TypeInference","doc":"Default type inference implementation.\n\nIf you desire to override it, simply do:\n\n    defmodule MyTypeInference do\n      use ExlasticSearch.TypeInference.Base\n\n      def infer(CustomType), do: :text # or whatever you chose\n      def infer(type), do: super(type)\n    end\n\nThen configure it with `config :exlasticsearch, :type_inference, MyTypeInference`","ref":"ExlasticSearch.TypeInference.html"},{"type":"function","title":"ExlasticSearch.TypeInference.infer/1","doc":"","ref":"ExlasticSearch.TypeInference.html#infer/1"},{"type":"behaviour","title":"ExlasticSearch.TypeInference.API","doc":"Behaviour for inferring module types.\n\nA default implementation is available in `ExlasticSearch.TypeInference.Base`","ref":"ExlasticSearch.TypeInference.API.html"},{"type":"callback","title":"ExlasticSearch.TypeInference.API.infer/1","doc":"","ref":"ExlasticSearch.TypeInference.API.html#c:infer/1"},{"type":"module","title":"ExlasticSearch.TypeInference.Base","doc":"Implementation of type infernce for builtin Ecto types.","ref":"ExlasticSearch.TypeInference.Base.html"},{"type":"extras","title":"ExlasticSearch","doc":"# ExlasticSearch\n\n[![Module Version](https://img.shields.io/hexpm/v/exlasticsearch.svg)](https://hex.pm/packages/exlasticsearch)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/exlasticsearch/)\n[![Total Download](https://img.shields.io/hexpm/dt/exlasticsearch.svg)](https://hex.pm/packages/exlasticsearch)\n[![License](https://img.shields.io/hexpm/l/exlasticsearch.svg)](https://github.com/Frameio/exlasticsearch/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/Frameio/exlasticsearch.svg)](https://github.com/Frameio/exlasticsearch/commits/master)\n\nAn [Elasticsearch](https://www.elastic.co/elasticsearch/) DSLs for mapping Ecto\nmodels to Elasticsearch mappings, along with Elixir friendly query wrappers,\nresponse formatting and the like.","ref":"readme.html"},{"type":"extras","title":"Installation - ExlasticSearch","doc":"```elixir\ndef deps do\n  [\n    {:exlasticsearch, \"~> 2.3.0\"}\n  ]\nend\n```\n\nDocs are available on [hex](https://hexdocs.pm/exlasticsearch/)","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ExlasticSearch","doc":"You can pair an `ExlasticSearch.Model` with an existing schema like:\n\n```elixir\ndefmodule MySchema do\n  # ...\n  use ExlasticSearch.Model\n\n  indexes :my_index do\n    settings Application.get_env(:some, :settings)\n\n    mapping :field\n    mapping :other_field, type: :keyword # ecto derived defaults can be overridden\n  end\nend\n```\n\nYou can then construct queries like so:\n\n```elixir\nMySchema.search_query()\n|> must(match(field, value))\n|> should(match_phrase(field, value, opts))\n|> filter(term(filter_field, value))\n```\n\nA repo model like Ecto is provided, so a with ability to do most restful operations on records, in\naddition to calling search APIs with the query structs above.\n\nIf additional data needs to be fetched or formatted prior to insertion into elastic, the `ExlasticSearch.Indexable`\nprotocol can be implemented to do that for you. A default implementation can also be generated as part of using\nthe `ExlasticSearch.Model` macro.","ref":"readme.html#usage"},{"type":"extras","title":"Configuration - ExlasticSearch","doc":"This library requires [Elastix](https://hex.pm/packages/elastix), an Elixir Elasticsearch HTTP client. So refer to it for any HTTP related configuration. In addition, there are the following configuration options:\n\n```elixir\nconfig :exlasticsearch, :type_inference, ExlasticSearch.TypeInference\n\nconfig :exlasticsearch, ExlasticSearch.Repo,\n  url: \"http://localhost:9200\",\n  json_library: Jason\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Copyright and License - ExlasticSearch","doc":"Copyright (c) 2025 Adobe/Frame.io\n\nThis software is released under the [MIT License](./LICENSE.md).","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2018 Frame.io\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}